@@ -30,7 +30,6 @@
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/file.h>
-#include <stropts.h>
 #include <poll.h>
 #include <time.h>
 
@@ -45,7 +44,6 @@
 #include <gpe/errorbox.h>
 #include <gpe/spacing.h>
 #include <gpe/pixmaps.h>
-#include <gpe/popup_menu.h>
 
 #include "cardinfo.h"
 #include "applets.h"
