@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *               2003,2004  Florian Boor <florian.boor@kernelconcepts.de>
+ *               2003 - 2005  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,13 +34,11 @@
 #include "cfgfile.h"
 #include "ownerinfo.h"
 #include "screen/brightness.h"
+#include "keys/keyboard.h"
 #ifndef DISABLE_XRANDR
 #include "screen/rotation.h"
 #endif
-#ifdef PACKAGETOOL		
-#include "packages.h"
-#include "keyboard.h"
-#endif
+
 #include "serial.h"
 #include "cardinfo.h"
 #include "timeanddate.h"
@@ -56,14 +54,6 @@ int check_root_passwd (const char *passwd);
 int check_user_access (const char *cmd);
 
 
-#ifdef PACKAGETOOL		
-void
-update_packages ()
-{
-	do_package_update ();
-}
-#endif
-
 void
 update_screen_brightness (int br)
 {
@@ -110,104 +100,6 @@ update_time_from_net (const gchar * server)
 }
 
 
-/* Changes a setting in a config file, to be used with caution.
- * seperator == 0 means to comment out this line 
- */
-
-void
-change_cfg_value (const gchar * file, const gchar * var, const gchar * val,
-		  gchar seperator)
-{
-	gchar *content, *tmpval;
-	gchar **lines = NULL;
-	gint length;
-	gchar *delim;
-	FILE *fnew;
-	gint i = 0;
-	gint j = 0;
-	GError *err = NULL;
-
-	tmpval = "";
-	delim = g_strdup ("\n");
-	if (!g_file_get_contents (file, &content, &length, &err))
-	{
-		fprintf (stderr, "Could not access file: %s.\n", file);
-		if (access (file, F_OK))	// file exists, but access is denied
-		{
-			i = 0;
-			delim = NULL;
-			goto writefile;
-		}
-	}
-	lines = g_strsplit (content, delim, 2048);
-	g_free (delim);
-	delim = NULL;
-	g_free (content);
-
-	while (lines[i])
-	{
-		if (g_str_has_prefix (g_strchomp (lines[i]), var))
-		{
-			delim = lines[i];
-			if (seperator)
-			{
-				j = get_first_char (delim);
-				if (j > 0)
-				{
-					tmpval = g_malloc (j+2);
-					strncpy (tmpval, delim, j);
-					tmpval[j]=0;
-					lines[i] =
-						g_strdup_printf ("%s%s%c%s", tmpval,
-								 var, seperator, val);
-					g_free (tmpval);
-				}
-				else
-				{
-					lines[i] =
-						g_strdup_printf ("%s%c%s", var,
-								 seperator, val);
-				}
-			}
-			else
-			{
-				lines[i] = g_strdup_printf ("# %s", lines[i]);
-			}
-		}
-		i++;
-	}
-
-	if (i)
-		i--;
-
-      writefile:
-
-	if ((delim == NULL) && val)
-	{
-		lines = realloc (lines, (i + 1) * sizeof (gchar *));
-		lines[i] = g_strdup_printf ("%s%c%s", var, seperator, val);
-		i++;
-		lines[i] = NULL;
-	}
-	else
-		free (delim);
-
-	fnew = fopen (file, "w");
-	if (!fnew)
-	{
-		fprintf (stderr, "Could not write to file: %s.\n", file);
-		return;
-	}
-
-	for (j = 0; j < i; j++)
-	{
-		fprintf (fnew, "%s\n", lines[j]);
-	}
-	fclose (fnew);
-	g_strfreev (lines);
-}
-
-
 void
 update_login_bg_sh (char *setupinfo)
 {
@@ -434,28 +326,6 @@ suidloop (int write, int read)
 					fscanf (in, "%100s", arg2);	// username
 					create_homedir (arg1, arg2);
 				}
-#ifdef PACKAGETOOL		
-				else if (strcmp (cmd, "NWUD") == 0)  // run system packages update
-				{
-					fscanf (in, "%100s", arg1);
-					update_packages ();
-				}
-				else if (strcmp (cmd, "NWIS") == 0)  // run package installation
-				{
-					fscanf (in, "%100s", arg1);
-					do_package_install (arg1,FALSE);
-				}
-				else if (strcmp (cmd, "NWRM") == 0)  // run package uninstall
-				{
-					fscanf (in, "%100s", arg1);
-					do_package_install (arg1,TRUE);
-				}
-				else if (strcmp (cmd, "PAIS") == 0)  // install a ipk package
-				{
-					fscanf (in, "%100s", arg1);
-					do_package_install (arg1,FALSE);
-				}
-#endif				
 				else if (strcmp (cmd, "SERU") == 0)  // change serial port usage
 				{
 					fscanf (in, "%d", &numarg);
@@ -505,13 +375,6 @@ suidloop (int write, int read)
 						       pcmcia_tmpcfgfile);
 					}
 				}
-#ifdef PACKAGETOOL		
-				else if (strcmp (cmd, "KBDC") == 0)  // write a new keyboard config file
-				{
-					fscanf (in, "%255s", arg1);
-					write_keyboard_cfg (arg1);
-				}
-#endif				
 				else if (strcmp (cmd, "GAUA") == 0)  // change user access to gpe-conf
 				{
 					fscanf (in, "%100s", arg1);
@@ -530,6 +393,12 @@ suidloop (int write, int read)
 					fscanf (in, "%100s", arg1);
 					set_autologin_setting(atol(arg1) ? TRUE : FALSE);
 				}
+				else if (strcmp (cmd, "KBDD") == 0)  /* Keyboard config */
+				{
+					fscanf (in, "%100s", arg1);
+					fscanf (in, "%100s", arg2);
+					keyboard_save(arg1, arg2);
+				}
 				else if (strcmp (cmd, "CHPW") == 0)  // change users password
 				{
 					struct passwd *pw;
